#
# spec file for package php-pear-Mail_Mime
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pear_name  Mail_Mime

Name:           php-pear-Mail_Mime
Version:        1.10.12
Release:        1.4
Summary:        PHP classes to create MIME messages
License:        BSD-3-Clause
Group:          Development/Libraries/Other
URL:            https://pear.php.net/package/%{pear_name}
Source:         https://pear.php.net/get/%{pear_name}-%{version}.tgz
BuildRequires:  php-devel
BuildRequires:  php-pear
Requires:       php-pear
Provides:       php-pear(%{pear_name}) = %{version}
# PHP5 last used in openSUSE:Leap_42.3
Provides:       php5-pear-%{pear_name} = %{version}
Obsoletes:      php5-pear-%{pear_name} < %{version}
Provides:       php7-pear-%{pear_name} = %{version}
Obsoletes:      php7-pear-%{pear_name} < %{version}
BuildArch:      noarch

%description
Mail_Mime provides classes to deal with the creation and manipulation
of MIME messages. It allows to create e-mail messages consisting of
text parts, HTML parts, inline HTML images, attachments and attached
(embedded) messages. It supports non-ASCII characters in filenames,
subjects, recipients, etc.

%prep
%setup -q -n %{pear_name}-%{version}
# move package.xml when needed
[ -f ../package.xml ] &&  mv ../package.xml . || :

%build

%install
%{__pear} install --nodeps --offline --packagingroot %{buildroot} package.xml
install -D -m 0644 package.xml %{buildroot}%{php_pearxmldir}/%{pear_name}.xml

%{php_pear_gen_filelist}

%post
if [ "$1" = "1" ]; then
  # on "rpm -ivh"
  %{__pear} install --nodeps --soft --force --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi
if [ "$1" = "2" ]; then
  # on "rpm -Uvh"
  %{__pear} upgrade --offline --register-only %{php_pearxmldir}/%{pear_name}.xml || :
fi

%postun
if [ "$1" = "0" ]; then
  # on "rpm -e"
  %{__pear} uninstall --nodeps --ignore-errors --register-only pear.php.net/%{pear_name} || :
fi

%files -f %{name}.files
%docdir %{pear_docdir}
%exclude %{pear_metadir}/.??*
%exclude %{pear_testdir}

%changelog
* Thu Mar 14 2024 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.12
  * Prevent from "PHP Deprecated: file_exists(): Passing null to
    parameter #1 ($filename) of type string"
  * PHPDoc improvements
* Fri Dec 10 2021 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.11
  * Fix PHP 8.1: strlen(): Passing null to parameter #1 ($string) of
    type string is deprecated
  * Fix encoding recipient names with @ character and no space between
    name and address
  * Fix the license label in composer.json
* Wed Jan 20 2021 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.10
  * Compatibility fixes for PHP 5.2 and 5.3
  * Corrected soft line breaks handling to be RFC compliant
  * Corrected line breaks for lines ending in dots and length more
    than 74
* Sun Jun 28 2020 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.9
  * Added a workaround for an opcache bug on OpenSuse 15.1
* Sun Jun 14 2020 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.8
  * Fix encoding issues with ISO-2022-JP-MS input labelled with
    ISO-2022-JP
* Fri Mar 20 2020 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.7
  * Fix invalid Content-Type for messages with only html part and
    inline images
* Wed Feb  5 2020 Arjen de Korte <suse+build@de-korte.org>
- new upstream release 1.10.6
  * Fix different boundary in headers and body when using headers()
    after get()
  * Removed phail.php script
- new upstream release 1.10.5
  * Make sure to not set Content-Transfer-Encoding on multipart messages
  * Added support for calendar invitations with attachments/html/images
* Thu Dec  5 2019 Arjen de Korte <suse+build@de-korte.org>
- make package PHP version independent
- new upstream release 1.10.4
  * Fix E_STRICT errors introduced in the previous release
  * Fix deprecation warning for get_magic_quotes_runtime() use on
    PHP 7.4
  * Fix Bug #21255: Boundary gets added twice when using
    setContentType()
  * PHP 7.2 compatibility fixes
- use correct macro to reference metadata (boo#1158112)
- clean-up spec, use https for downloading
* Wed Nov  8 2017 jweberhofer@weberhofer.at
- Move to new unified spec
* Wed Nov  8 2017 jweberhofer@weberhofer.at
- Cleaned up spec
* Fri Nov  3 2017 jengelh@inai.de
- Update description with spelling fixes and better read flow.
* Sun Sep 10 2017 jweberhofer@weberhofer.at
- Removed circular dependency to php-pear(Mail_mimeDecode)
- Cleaned up spec
* Fri Aug 18 2017 ecsos@opensuse.org
- New upstream release 1.10.1
- renamed package to php7-pear-Mail_Mime
* Tue Sep 15 2015 aj@ajaissle.de
- New upstream release 1.10.0
  * Add possibility to add externally created Mail_mimePart objects as attachments [alec]
  * Add possibility to set preamble text for multipart messages [alec]
- Changes 1.9.0
  * Bug #20921: Make Mail_mimePart::encodeHeaderValue() a static method [alec]
  * Bug #20931: Really remove unset headers [alec]
  * Request #18772: Added methods for creating text/calendar messages [alec]
* Thu Dec 11 2014 aj@ajaissle.de
- New upstream release 1.8.9
  * Fixed Bug #20273: Incorrect handling of HTAB in encodeHeader() [alec]
  * Fixed Bug #20226: Mail_mimePart::encodeHeader does not encode ISO-2022-JP string [alec]
  * Fixed Bug #20222: Broken Compatybility with PHP4 [alec]
* Fri Nov  8 2013 aj@ajaissle.de
- New upstream release 1.8.8
  * Fixed warning/notice on (static vs. non-static) PEAR::raiseError() usage [alec]
  * Fixed Bug #19761: PHP5 warnings about return by reference [alec]
  * Fixed Bug #19770: Make cid generator more unique on Windows [alec]
  * Fixed Bug #19987: E_STRICT warning when null is passed by reference [alec]
* Fri Feb  1 2013 aj@ajaissle.de
- New upstram version 1.8.7
- Changelog 1.8.7
  * Bug #5333: Fix more return by reference errors [alec]
  * Bug #19754: Fix compatibility with PHP4 [alec]
- Changelog 1.8.6
  * Bug #19473: PEAR::isError() compatibility problem with PHP 5.4 [alec]
  * Bug #19497: Attachment filename is cut on slash character [alec]
  * Bug #19665: Add Mail-Reply-To and Mail-Followup-To to structured recipient headers list [alec]
- Changelog 1.8.5
  * Added possibility to set additional parameters of message part header, e.g. attachment size [alec]
  * Added automatic setting of attachment size via Content-Disposition header size parameter [alec]
- Changelog 1.8.4
  * Request #19406: Allow to set individual attachment part headers
    [alec]
  * Fixed Bug #18982: Non-static method Mail
    mimePart::encodeHeader() should not be called statically [alec]
- Changelog 1.8.3
  * Request #19009: Remove error_reporting from tests [alec]
  * Fixed Bug #19094: Email addresses do not have to contain a
    space between the name and address part [alec]
  * Fixed Bug #19328: Wrong encoding of filenames with comma [alec]
- Changelog 1.8.2
  * #18426: Fixed backward compatibility for "dfilename" parameter
    [alec]
  * Removed xmail.dtd, xmail.xsl from the package [alec]
  * Fixed handling of email addresses with quoted local part [alec]
* Thu Jan 12 2012 coolo@suse.com
- change license to be in spdx.org format
* Thu Jan 20 2011 chris@computersalat.de
- change to php_pear_gen_filelist macro
* Wed Jan 19 2011 chris@computersalat.de
- pkg rename php5-pear-Mail_Mime
- merge with php-pear-mail_mime, php5-pear-mail_mime
- update to 1.8.1
  * #18083: Not possible to set separate charset for attachment content
    and headers [alec]
- 1.8.0
  Bugs Fixed:
  * Double-addition of e-mail domain to content ID in HTML images [alec]
  * #17311: Multi-octet characters are split across adjacent
    'encoded-word's [alec]
  * #17573: Place charset parameter in first line of Content-Type header
    (if possible) [alec]
  Implemented Features:
  * #17518: addTo() method [alec]
- added php-macros
- cleanup spec
* Sat May 30 2009 chris@computersalat.de
- fixed post script
* Thu May 21 2009 chris@computersalat.de
- new version 1.5.2
- beautify spec
  o new spec header
  o package rename due to package convention
  o removed php4 stuff, deps
  o added Provides and Obsoletes for old package names.
    This should not break deps
- added stuff to automatically create correct filelist
  o tested against Factory (1120)
  o opensuse >= 1100 complains about
    "directory not owned by package"
- some rpmlint stuff
* Tue Dec 23 2008 rbos@opensuse.org
- Changed the pear install command, use package.xml instead of the tarbal
* Sat Jun 17 2006 suse-tux@gmx.de
- made spec file portable for older/new suse-versions
- removed #usedforbuild, added %%%%clean-macro
- added rpmmacros (changed "mv" to "%%%%__mv" etc.)
- removed Packager-tag :)
* Sun Jun 11 2006 suse-tux@gmx.de
- built for 10.0 because it's missing there
- added Packager-tag
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jan 19 2006 mmarek@suse.de
- fix filelist, remove temporary files created by pear installer
- unify php5-pear-*.spec files
- increase php's memory_limit during installation (parsing
  xml needs more than default 8M sometimes)
* Mon Jan 16 2006 mmarek@suse.cz
- created package to satisfy horde dependencies
